@@ -32,7 +32,8 @@ import (
 	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha2"
 	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha3"
 	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha4"
-	defaultConfig "github.com/k3d-io/k3d/v5/pkg/config/v1alpha4"
+	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha5"
+	defaultConfig "github.com/k3d-io/k3d/v5/pkg/config/v1alpha5"
 
 	types "github.com/k3d-io/k3d/v5/pkg/config/types"
 )
@@ -43,6 +44,7 @@ var Schemas = map[string]string{
 	v1alpha2.ApiVersion: v1alpha2.JSONSchema,
 	v1alpha3.ApiVersion: v1alpha3.JSONSchema,
 	v1alpha4.ApiVersion: v1alpha4.JSONSchema,
+	v1alpha5.ApiVersion: v1alpha5.JSONSchema,
 }
 
 func GetSchemaByVersion(apiVersion string) ([]byte, error) {
@@ -54,7 +56,6 @@ func GetSchemaByVersion(apiVersion string) ([]byte, error) {
 }
 
 func FromViper(config *viper.Viper) (types.Config, error) {
-
 	var cfg types.Config
 	var err error
 
@@ -70,6 +71,8 @@ func FromViper(config *viper.Viper) (types.Config, error) {
 		cfg, err = v1alpha3.GetConfigByKind(kind)
 	case "k3d.io/v1alpha4":
 		cfg, err = v1alpha4.GetConfigByKind(kind)
+	case "k3d.io/v1alpha5":
+		cfg, err = v1alpha5.GetConfigByKind(kind)
 	case "":
 		cfg, err = defaultConfig.GetConfigByKind(kind)
 	default:
@@ -93,6 +96,8 @@ func getMigrations(version string) map[string]func(types.Config) (types.Config,
 		return v1alpha3.Migrations
 	case v1alpha4.ApiVersion:
 		return v1alpha4.Migrations
+	case v1alpha5.ApiVersion:
+		return v1alpha5.Migrations
 	default:
 		return nil
 	}
